@@ -35,7 +35,7 @@ def get_username(strategy, details, user=None, *args, **kwargs):
         # Generate a unique username for current user using username
         # as base but adding a unique hash at the end. Original
         # username is cut to avoid any field max_length.
-        while storage.user.user_exists(final_username):
+        while storage.user.user_exists(username=final_username):
             username = short_username + uuid4().hex[:uuid_length]
             final_username = username[:max_length]
             if do_clean:
